@@ -21,17 +21,17 @@
 #include <config.h>
 #endif
 
-#include <ntqevent.h>
-#include <ntqdragobject.h>
-#include <ntqfile.h>
-#include <ntqvaluelist.h>
-#include <ntqcursor.h>
-#include <ntqbuffer.h>
-#include <ntqlistview.h>
-#include <ntqclipboard.h>
-#include <ntqheader.h>
-#include <ntqtextstream.h>
-#include <ntqtimer.h>
+#include <tqevent.h>
+#include <tqdragobject.h>
+#include <tqfile.h>
+#include <tqvaluelist.h>
+#include <tqcursor.h>
+#include <tqbuffer.h>
+#include <tqlistview.h>
+#include <tqclipboard.h>
+#include <tqheader.h>
+#include <tqtextstream.h>
+#include <tqtimer.h>
 
 #include <tdeapplication.h>
 #include <tdeio/netaccess.h>
@@ -46,24 +46,24 @@
 #include <kprogress.h>
 #include <kiconloader.h>
 
-#include <kbibtex_part.h>
-#include <documentlistviewitem.h>
-#include <file.h>
-#include <fileimporterbibutils.h>
-#include <fileimporterris.h>
-#include <fileimporterbibtex.h>
-#include <fileexporterbibtex.h>
-#include <element.h>
-#include <entry.h>
-#include <macro.h>
-#include <comment.h>
-#include <preamblewidget.h>
-#include <preamble.h>
-#include <entrywidget.h>
-#include <commentwidget.h>
-#include <macrowidget.h>
-#include <settings.h>
-#include <encoderlatex.h>
+#include "kbibtex_part.h"
+#include "documentlistviewitem.h"
+#include "file.h"
+#include "fileimporterbibutils.h"
+#include "fileimporterris.h"
+#include "fileimporterbibtex.h"
+#include "fileexporterbibtex.h"
+#include "element.h"
+#include "entry.h"
+#include "macro.h"
+#include "comment.h"
+#include "preamblewidget.h"
+#include "preamble.h"
+#include "entrywidget.h"
+#include "commentwidget.h"
+#include "macrowidget.h"
+#include "settings.h"
+#include "encoderlatex.h"
 
 #include "documentlistview.h"
 
@@ -659,7 +659,7 @@ namespace KBibTeX
         TQStrList urlList;
 
         if ( TQTextDrag::decode( event, text ) && KURL( text ).isValid() )
-            urlList.append( text );
+            urlList.append( text.utf8() );
 
         if ( !urlList.isEmpty() || TQUriDrag::decode( event, urlList ) )
         {
