@@ -19,19 +19,19 @@
 ***************************************************************************/
 #include <cmath>
 
-#include <ntqlayout.h>
-#include <ntqfile.h>
-#include <ntqdragobject.h>
-#include <ntqregexp.h>
-#include <ntqsplitter.h>
-#include <ntqurl.h>
-#include <ntqtextedit.h>
-#include <ntqprogressdialog.h>
-#include <ntqbuffer.h>
-#include <ntqtooltip.h>
-#include <ntqapplication.h>
-#include <ntqpushbutton.h>
-#include <ntqfileinfo.h>
+#include <tqlayout.h>
+#include <tqfile.h>
+#include <tqdragobject.h>
+#include <tqregexp.h>
+#include <tqsplitter.h>
+#include <tqurl.h>
+#include <tqtextedit.h>
+#include <tqprogressdialog.h>
+#include <tqbuffer.h>
+#include <tqtooltip.h>
+#include <tqapplication.h>
+#include <tqpushbutton.h>
+#include <tqfileinfo.h>
 
 #include <kdebug.h>
 #include <tdelocale.h>
@@ -53,39 +53,39 @@
 #include <config.h>
 #endif
 
-#include <searchbar.h>
-#include <sidebar.h>
-#include <documentlistview.h>
-#include <documentlistviewitem.h>
-#include <documentsourceview.h>
-#include <macrowidget.h>
-#include <preamblewidget.h>
-#include <commentwidget.h>
-#include <entrywidget.h>
-#include <fileimporterbibtex.h>
-#include <fileimporterbibutils.h>
-#include <fileimporterris.h>
-#include <fileexporterbibtex.h>
-#include <fileexporterbibutils.h>
-#include <fileexporterris.h>
-#include <fileexporterxml.h>
-#include <fileexporterrtf.h>
-#include <fileexporterdocbook5.h>
-#include <fileexporterpdf.h>
-#include <fileexporterps.h>
-#include <fileexporterxslt.h>
-#include <fileimporterexternal.h>
-#include <fileexporterexternal.h>
-#include <xsltransform.h>
-#include <entry.h>
-#include <entryfield.h>
-#include <comment.h>
-#include <macro.h>
-#include <preamble.h>
-#include <settings.h>
-#include <webquery.h>
-#include <mergeelements.h>
-#include <idsuggestions.h>
+#include "searchbar.h"
+#include "sidebar.h"
+#include "documentlistview.h"
+#include "documentlistviewitem.h"
+#include "documentsourceview.h"
+#include "macrowidget.h"
+#include "preamblewidget.h"
+#include "commentwidget.h"
+#include "entrywidget.h"
+#include "fileimporterbibtex.h"
+#include "fileimporterbibutils.h"
+#include "fileimporterris.h"
+#include "fileexporterbibtex.h"
+#include "fileexporterbibutils.h"
+#include "fileexporterris.h"
+#include "fileexporterxml.h"
+#include "fileexporterrtf.h"
+#include "fileexporterdocbook5.h"
+#include "fileexporterpdf.h"
+#include "fileexporterps.h"
+#include "fileexporterxslt.h"
+#include "fileimporterexternal.h"
+#include "fileexporterexternal.h"
+#include "xsltransform.h"
+#include "entry.h"
+#include "entryfield.h"
+#include "comment.h"
+#include "macro.h"
+#include "preamble.h"
+#include "settings.h"
+#include "webquery.h"
+#include "mergeelements.h"
+#include "idsuggestions.h"
 
 #include "documentwidget.h"
 
