@@ -17,15 +17,15 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqstring.h>
-#include <ntqregexp.h>
-#include <ntqlayout.h>
-#include <ntqheader.h>
-#include <ntqtimer.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqpushbutton.h>
-#include <ntqcheckbox.h>
+#include <tqstring.h>
+#include <tqregexp.h>
+#include <tqlayout.h>
+#include <tqheader.h>
+#include <tqtimer.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqpushbutton.h>
+#include <tqcheckbox.h>
 
 #include <tdelistview.h>
 #include <klineedit.h>
@@ -34,9 +34,9 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 
-#include <value.h>
-#include <valuewidget.h>
-#include <settings.h>
+#include "value.h"
+#include "valuewidget.h"
+#include "settings.h"
 #include "fieldlistview.h"
 
 namespace KBibTeX
