@@ -17,11 +17,11 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqapplication.h>
-#include <ntqtextstream.h>
-#include <ntqregexp.h>
+#include <tqapplication.h>
+#include <tqtextstream.h>
+#include <tqregexp.h>
 
-#include <entry.h>
+#include "entry.h"
 
 #include "fileimporterris.h"
 
