@@ -17,14 +17,14 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqregexp.h>
+#include <tqregexp.h>
 
 #include <tdelocale.h>
 
-#include <encoderlatex.h>
-#include <file.h>
-#include <settings.h>
-#include <entry.h>
+#include "encoderlatex.h"
+#include "file.h"
+#include "settings.h"
+#include "entry.h"
 #include "idsuggestions.h"
 
 namespace KBibTeX
