@@ -17,12 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqspinbox.h>
-#include <ntqlabel.h>
-#include <ntqcheckbox.h>
-#include <ntqobjectlist.h>
-#include <ntqscrollview.h>
+#include <tqlayout.h>
+#include <tqspinbox.h>
+#include <tqlabel.h>
+#include <tqcheckbox.h>
+#include <tqobjectlist.h>
+#include <tqscrollview.h>
 
 #include <tdeglobalsettings.h>
 #include <klineedit.h>
@@ -33,9 +33,9 @@
 #include <kiconloader.h>
 #include <tdelocale.h>
 
-#include <idsuggestions.h>
-#include <fileimporter.h>
-#include <fileimporterbibtex.h>
+#include "idsuggestions.h"
+#include "fileimporter.h"
+#include "fileimporterbibtex.h"
 #include "idsuggestionswidget.h"
 
 #define min(a,b)  ((a)>(b)?(b):(a))
