@@ -33,7 +33,7 @@
 #include "iso6937converter.h"
 #include <kdebug.h>
 
-#include <ntqstring.h>
+#include <tqstring.h>
 
 using KBibTeX::Iso6937Converter;
 
