@@ -19,10 +19,10 @@
  ***************************************************************************/
 #include <cmath>
 
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqprogressbar.h>
-#include <ntqtimer.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqprogressbar.h>
+#include <tqtimer.h>
 
 #include <tdelocale.h>
 #include <kpushbutton.h>
@@ -33,14 +33,14 @@
 #include <tdeconfig.h>
 #include <twin.h>
 
-#include <macro.h>
-#include <comment.h>
-#include <preamble.h>
-#include <macrowidget.h>
-#include <entrywidget.h>
-#include <preamblewidget.h>
-#include <settings.h>
-#include <fileexporterbibtex.h>
+#include "macro.h"
+#include "comment.h"
+#include "preamble.h"
+#include "macrowidget.h"
+#include "entrywidget.h"
+#include "preamblewidget.h"
+#include "settings.h"
+#include "fileexporterbibtex.h"
 #include "mergeelements.h"
 
 namespace KBibTeX
