@@ -17,8 +17,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqlabel.h>
-#include <ntqlayout.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
 
 #include <kdialogbase.h>
 #include <tdelocale.h>
