@@ -17,19 +17,19 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqtimer.h>
-#include <ntqheader.h>
-#include <ntqwidget.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqframe.h>
-#include <ntqwidgetstack.h>
-#include <ntqlabel.h>
-#include <ntqcheckbox.h>
-#include <ntqspinbox.h>
-#include <ntqapplication.h>
-#include <ntqeventloop.h>
-#include <ntqbuffer.h>
+#include <tqtimer.h>
+#include <tqheader.h>
+#include <tqwidget.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqframe.h>
+#include <tqwidgetstack.h>
+#include <tqlabel.h>
+#include <tqcheckbox.h>
+#include <tqspinbox.h>
+#include <tqapplication.h>
+#include <tqeventloop.h>
+#include <tqbuffer.h>
 
 #include <tdelocale.h>
 #include <kcombobox.h>
@@ -45,25 +45,25 @@
 #include <tdeconfig.h>
 #include <twin.h>
 
-#include <settings.h>
-#include <idsuggestions.h>
-#include <entrywidget.h>
-#include <webqueryarxiv.h>
-#include <webquerybibsonomy.h>
-#include <webquerycsb.h>
-#include <webquerycitebase.h>
-#include <webqueryciteseerx.h>
-#include <webquerydblp.h>
-#include <webquerygooglescholar.h>
-#include <webqueryieeexplore.h>
-#include <webquerymathscinet.h>
-#include <webquerypubmed.h>
-#include <webquerysciencedirect.h>
-#include <webqueryspireshep.h>
+#include "settings.h"
+#include "idsuggestions.h"
+#include "entrywidget.h"
+#include "webqueryarxiv.h"
+#include "webquerybibsonomy.h"
+#include "webquerycsb.h"
+#include "webquerycitebase.h"
+#include "webqueryciteseerx.h"
+#include "webquerydblp.h"
+#include "webquerygooglescholar.h"
+#include "webqueryieeexplore.h"
+#include "webquerymathscinet.h"
+#include "webquerypubmed.h"
+#include "webquerysciencedirect.h"
+#include "webqueryspireshep.h"
 #ifdef HAVE_YAZ
-#include <webqueryz3950.h>
+#include "webqueryz3950.h"
 #endif // HAVE_YAZ
-#include <webqueryzmath.h>
+#include "webqueryzmath.h"
 #include "webquery.h"
 
 #define min(a,b) ((a)>(b)?(b):(a))
