@@ -17,12 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqfile.h>
-#include <ntqapplication.h>
-#include <ntqregexp.h>
-#include <ntqtimer.h>
-#include <ntqmap.h>
-#include <ntqspinbox.h>
+#include <tqfile.h>
+#include <tqapplication.h>
+#include <tqregexp.h>
+#include <tqtimer.h>
+#include <tqmap.h>
+#include <tqspinbox.h>
 #include <tdeconfig.h>
 
 #include <klineedit.h>
@@ -33,7 +33,7 @@
 
 #include <dcopref.h>
 
-#include <settings.h>
+#include "settings.h"
 #include "webquerygooglescholar.h"
 
 namespace KBibTeX
