@@ -17,14 +17,14 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqwidget.h>
-#include <ntqdom.h>
-#include <ntqapplication.h>
-#include <ntqstringlist.h>
-#include <ntqbuffer.h>
-#include <ntqcstring.h>
-#include <ntqregexp.h>
-#include <ntqspinbox.h>
+#include <tqwidget.h>
+#include <tqdom.h>
+#include <tqapplication.h>
+#include <tqstringlist.h>
+#include <tqbuffer.h>
+#include <tqcstring.h>
+#include <tqregexp.h>
+#include <tqspinbox.h>
 
 #include <klineedit.h>
 #include <kdialog.h>
@@ -33,9 +33,9 @@
 #include <tdemessagebox.h>
 #include <tdeio/netaccess.h>
 
-#include <entryfield.h>
-#include <value.h>
-#include <settings.h>
+#include "entryfield.h"
+#include "value.h"
+#include "settings.h"
 #include "webquerypubmed.h"
 
 namespace KBibTeX
