@@ -17,11 +17,11 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqfile.h>
-#include <ntqapplication.h>
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqcheckbox.h>
+#include <tqfile.h>
+#include <tqapplication.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqcheckbox.h>
 
 #include <kiconloader.h>
 #include <kcombobox.h>
@@ -32,8 +32,8 @@
 #include <tdeio/netaccess.h>
 #include <kurl.h>
 
-#include <settings.h>
-#include <fileimporterbibtex.h>
+#include "settings.h"
+#include "fileimporterbibtex.h"
 #include "webqueryspireshep.h"
 
 namespace KBibTeX
